#
# spec file for package plasma6-mobile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# org.kde.phone.homescreen, org.kde.plasma.phone.taskpanel and org.kde.private.mobile.homescreen.folio are internal,
# MeeGo.QOfono is optional and not packaged yet
%global __requires_exclude qmlimport\\((org\\.kde\\.phone\\.homescreen|org\\.kde\\.plasma\\.phone\\.taskpanel|org\\.kde\\.private\\.mobile\\.homescreen\\.folio|MeeGo\\.QOfono|).*

%define kf6_version 6.0.0
%define qt6_version 6.6.0

%define rname plasma-mobile
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           plasma6-mobile
Version:        6.0.5
%global _plasma6_bugfix 6.0.3
Release:        1.1
# Full Plasma 6 version (e.g. 5.9.3)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        Plasma shell for mobile devices
License:        GPL-2.0-or-later
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6ModemManagerQt) >= %{kf6_version}
BuildRequires:  cmake(KF6NetworkManagerQt) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6Screen) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KPipeWire) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KWayland) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KWin) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KWinDBusInterface) >= %{_plasma6_bugfix}
BuildRequires:  cmake(LibKWorkspace) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Plasma) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaQuick) >= %{_plasma6_bugfix}
BuildRequires:  cmake(QCoro6)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Sensors) >= %{qt6_version}
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(xcb)
# For plasma-open-settings
Requires:       kde-cli-tools6 >= %{_plasma6_bugfix}
Provides:       plasma5-mobile = %{version}
Obsoletes:      plasma5-mobile < %{version}
Obsoletes:      plasma5-mobile-lang < %{version}
# Forced on startup
Requires:       qqc2-breeze-style6
# QML imports
Requires:       kf6-bluez-qt-imports >= %{kf6_version}
Requires:       kf6-kdeclarative-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kwin6 >= %{_plasma6_bugfix}
Requires:       milou6 >= %{_plasma6_bugfix}
Requires:       plasma6-nano >= %{_plasma6_bugfix}
Requires:       plasma6-nm >= %{_plasma6_bugfix}
Requires:       plasma6-pa >= %{_plasma6_bugfix}
Requires:       plasma6-workspace >= %{_plasma6_bugfix}
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-qt5compat-imports >= %{qt6_version}
Requires:       qt6-wayland >= %{qt6_version}
# For KCM .desktop files
Requires:       systemsettings6 >= %{_plasma6_bugfix}

%description
Plasma shell for mobile devices.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%fdupes %{buildroot}

%files
%license LICENSES/*
%{_kf6_applicationsdir}/kcm_cellular_network.desktop
%{_kf6_applicationsdir}/kcm_mobile_hotspot.desktop
%{_kf6_applicationsdir}/kcm_mobile_info.desktop
%{_kf6_applicationsdir}/kcm_mobile_onscreenkeyboard.desktop
%{_kf6_applicationsdir}/kcm_mobile_power.desktop
%{_kf6_applicationsdir}/kcm_mobile_time.desktop
%{_kf6_applicationsdir}/kcm_mobile_wifi.desktop
%{_kf6_applicationsdir}/kcm_mobileshell.desktop
%{_kf6_appstreamdir}/org.kde.breeze.mobile.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobile.homescreen.folio.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobile.homescreen.halcyon.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobile.panel.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobile.taskpanel.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileinitialstart.cellular.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileinitialstart.finished.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileinitialstart.prepare.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileinitialstart.time.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileinitialstart.wifi.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.mobileshell.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.airplanemode.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.audio.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.battery.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.bluetooth.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.caffeine.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.donotdisturb.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.flashlight.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.hotspot.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.keyboardtoggle.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.mobiledata.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.nightcolor.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.powermenu.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.screenrotation.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.screenshot.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.settingsapp.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksetting.wifi.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.quicksettings.docked.appdata.xml
%{_kf6_bindir}/plasma-mobile-envmanager
%{_kf6_bindir}/plasma-mobile-initial-start
%{_kf6_bindir}/startplasmamobile
%{_kf6_dbusinterfacesdir}/org.kde.plasmashell.Mobile.xml
%{_kf6_notificationsdir}/plasma_mobile_quicksetting_screenshot.notifyrc
%dir %{_kf6_plasmadir}/look-and-feel
%{_kf6_plasmadir}/look-and-feel/org.kde.breeze.mobile/
%dir %{_kf6_plasmadir}/mobileinitialstart
%{_kf6_plasmadir}/mobileinitialstart/org.kde.plasma.mobileinitialstart.cellular/
%{_kf6_plasmadir}/mobileinitialstart/org.kde.plasma.mobileinitialstart.finished/
%{_kf6_plasmadir}/mobileinitialstart/org.kde.plasma.mobileinitialstart.prepare/
%{_kf6_plasmadir}/mobileinitialstart/org.kde.plasma.mobileinitialstart.time/
%{_kf6_plasmadir}/mobileinitialstart/org.kde.plasma.mobileinitialstart.wifi/
%dir %{_kf6_plasmadir}/plasmoids/
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.mobile.homescreen.folio/
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.mobile.homescreen.halcyon/
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.mobile.panel/
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.mobile.taskpanel/
%dir %{_kf6_plasmadir}/quicksettings
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.airplanemode/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.audio/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.battery/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.bluetooth/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.caffeine/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.donotdisturb/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.flashlight/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.hotspot/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.keyboardtoggle/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.mobiledata/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.nightcolor/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.powermenu/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.screenrotation/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.screenshot/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.settingsapp/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksetting.wifi/
%{_kf6_plasmadir}/quicksettings/org.kde.plasma.quicksettings.docked/
%dir %{_kf6_plasmadir}/shells
%{_kf6_plasmadir}/shells/org.kde.plasma.mobileshell/
%{_kf6_plugindir}/kf6/kded/kded_plasma_mobile_start.so
%dir %{_kf6_plugindir}/kwin
%dir %{_kf6_plugindir}/kwin/effects
%dir %{_kf6_plugindir}/kwin/effects/plugins
%{_kf6_plugindir}/kwin/effects/plugins/mobiletaskswitcher.so
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.mobile.homescreen.folio.so
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.mobile.homescreen.halcyon.so
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.mobile.panel.so
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.mobile.taskpanel.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_cellular_network.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_hotspot.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_info.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_onscreenkeyboard.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_power.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_time.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobile_wifi.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_mobileshell.so
%dir %{_kf6_qmldir}/org/kde/plasma/
%{_kf6_qmldir}/org/kde/plasma/mm/
%{_kf6_qmldir}/org/kde/plasma/mobileinitialstart/
%dir %{_kf6_qmldir}/org/kde/plasma/private/
%{_kf6_qmldir}/org/kde/plasma/private/mobileshell/
%dir %{_kf6_qmldir}/org/kde/plasma/quicksetting/
%{_kf6_qmldir}/org/kde/plasma/quicksetting/flashlight/
%{_kf6_qmldir}/org/kde/plasma/quicksetting/nightcolor/
%{_kf6_qmldir}/org/kde/plasma/quicksetting/powermenu/
%{_kf6_qmldir}/org/kde/plasma/quicksetting/screenrotation/
%{_kf6_qmldir}/org/kde/plasma/quicksetting/screenshot/
%{_kf6_qmldir}/org/kde/private/mobile/
%dir %{_kf6_sharedir}/kwin
%dir %{_kf6_sharedir}/kwin/effects
%{_kf6_sharedir}/kwin/effects/mobiletaskswitcher/
%dir %{_kf6_sharedir}/kwin/scripts
%{_kf6_sharedir}/kwin/scripts/convergentwindows/
%dir %{_kf6_sharedir}/wayland-sessions
%{_kf6_sharedir}/wayland-sessions/plasma-mobile.desktop

%files lang -f %{name}.lang

%changelog
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * [kcms/power] Rename translation catalog to match plugin name
  * update version for new release
  * navigationpanel: Remove feature that moves it to the right
    when the screen height is small
* Wed Mar 27 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3.1
- Changes since 6.0.3:
  * navigationpanel: Remove feature that moves it to the right when the screen height is small
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * volumeosd: Properly bind volume keys Partially addresses https://invent.kde.org/plasma/plasma-mobile/-/issues/328
  * kcms/time: Fix timezone dialog constantly popping up and down the keyboard while typing We need to ensure that there isn't an index set on the listview
  * components/mobileshell: Don't tie MarqueeLabel durations to kirigami duration lengths Otherwise setting the animation speed will affect the MarqueeLabel speed, which will look very glitched if it's fast.
  * homescreens/folio: Minimize all windows when pressing start key rather than activate "show desktop" mode Fixes https://invent.kde.org/plasma/plasma-mobile/-/issues/333
  * navigationpanel: Fix remnants of gesture-only setting affecting panel height BUG: 483663 (kde#483663)
  * taskpanel: Fix close vkbd button not showing
  * initialstart: Ensure initial value of 24 hour switch is obtained Otherwise the switch's state is always off.
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
  * widgets/mediacontrols: Fix base model reference
  * widgets/mediacontrols: Fix uncentered icon in buttons Use QQC2 components instead of PC3 components, now that theming works properly
  * lookandfeel: Sync with breeze, fix default cursor theme BUG: 482863 Not having a cursor theme set seems to cause the cursor to not show up at all (kde#482863)
  * widgets/mediacontrols: Ensure multiplexer does not show Fixes https://invent.kde.org/plasma/plasma-mobile/-/issues/261
  * envmanager: Set Placement mode for KWin to skip window maximize animation when not in docked mode We can use the placement mode setting in KWin to bypass the need to "maximize" after the window opens, KWin does this for us.
  * taskswitcher: Fix navigation panel position when in landscape mode It used to get confused when in landscape mode, but the navigation panel is on the bottom of the screen.
  * initialstart/time: Fix search box getting unfocused on every key press Fixes https://invent.kde.org/plasma/plasma-mobile/-/issues/288
  * homescreens/folio: Fix start button behaviour, ensure windows are minimized and it's not triggered in docked mode BUG: 482870 (kde#482870)
  * taskswitcher: Do not show apps marked as "skipSwitcher"
  * kwin/convergentwindows: Don't maximize xwaylandvideobridge ghost window
  * homescreens/folio: Improve performance of wallpaper blur, and enable by default Fixes https://invent.kde.org/plasma/plasma-mobile/-/issues/306
  * homescreens/folio: Prevent items from being added to favourites area if it's full Fixes https://invent.kde.org/plasma/plasma-mobile/-/issues/323
  * systemdialog: Update to match plasma-workspace implementation, and simplify UI SystemDialog was added in 2021 and did not receive any testing while the API was in flux when portals started using it.
  * homescreens/folio: Fix deleting delegates from folder not working
  * Fix low inertia scrolling with shell flickables See https://invent.kde.org/teams/plasma-mobile/issues/-/issues/273
  * homescreens/folio: Fix widget full representation being shown when starting drag and drop It's unnecessary to set the anchors on the full representation; it causes it to also show when the minimized representation is presented.
  * homescreens/folio: Delete empty page at end if last delegate is deleted
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
  * kwin/convergentwindows: Don't set maximize property for fullscreen windows Followup to https://invent.kde.org/teams/plasma-mobile/issues/-/issues/256
  * meta: Fix appstream tests
  * meta: Add tag to posix test
  * taskswitcher: Remove all interaction restrictions while the task switcher is opening This allows users to properly interact (open apps, dismiss) while the task switcher is in its opening animation.
  * kwin/convergentwindows: Fix race condition causing windows to be maximized too large See https://invent.kde.org/teams/plasma-mobile/issues/-/issues/256
  * taskpanel: Delay setting panel position on screen change, so shell doesn't crash Setting it immediately seems to trigger an underlying bug that causes the shell to crash, see https://invent.kde.org/plasma/plasma-mobile/-/issues/321
  * homescreens/folio: Don't show background for widget configure dialog https://invent.kde.org/plasma/plasma-mobile/-/issues/320 We seem to encounter an issue when a widget is deleted where the background stays. Workaround it for now.
* Tue Mar  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Require systemsettings6
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * kcms/mobiledata: Clarify behavior when networkmanager wwanEnabled is off In NetworkManager, there is a global "wwanEnabled" setting. We do not typically deal with this because toggling it off shuts off cellular in ModemManager (the mobile data toggle just disconnects the connection instead).
  * kwin/mobiletaskswitcher: make touchscreen swipe gesture use 3 fingers
  * kwin/mobiletaskswither: remove the touchpad gesture
  * kcms/wifi: Fix wi-fi dialog position, port to Kirigami.Dialog The Wi-Fi dialog position currently goes under the keyboard, fix it by porting to Kirigami.Dialog
  * homescreens/folio: Add arrow if there is one page Show arrow to open app drawer if there is only one page. Open the app drawer if it is tapped.
  * lockscreen: Remove bottom arrow animation Wastes battery as it keeps running with the display off
  * homescreens/folio: Add setting to toggle wallpaper blur, and disable by default
  * Adapt to renamed night light d-bus interface
  * bin: Add Type=Application to dev session .desktop file It's part of the specification
  * bin: Add POSIX shell linter and ensure scripts are compliant
  * quicksettings/screenrotation: Fix initial state of quicksetting always being off
  * update version for new release
  * initialstart: Ensure background image accounts for widescreen, and raise resolution
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * 6.0 RC version dep
  * add a version for dependencies so it does not break CI https://invent.kde.org/plasma/bluedevil/-/merge_requests/156
  * Improve wallpaper handling in initial start
  * Port intial start module to declarative qml type registration
  * kcms/powermanagement: Move from power-management category up a level
  * homescreens/folio: Remove unused plugin directory
  * kcms/mobileshell: Remove gesture only navigation option for now The KWin gesture currently does not work at all, so turning off the navigation panel makes it so the user cannot navigate.
  * Fix crash in envmanager
  * Find white torch
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Aug 25 2023 Christophe Marin <christophe@krop.fr>
- Init plasma6-mobile
